@@ -1,7 +1,5 @@
 package AptPkg::Source;
 
-# $Id: Source.pm,v 1.3 2004-06-20 12:17:33 bod Exp $
-
 require 5.005_62;
 use strict;
 use warnings;
@@ -12,13 +10,13 @@ require Exporter;
 
 our @ISA = qw(Exporter AptPkg::hash);
 our @EXPORT = ();
-our $VERSION = qw$Revision: 1.3 $[1] || 0.1;
+our $VERSION = 1.4;
 
 sub new
 {
     my $class = shift;
-    my $srclist = AptPkg::_pkg_source_list->new(@_);
-    my $xs = AptPkg::_pkg_src_records->new($srclist);
+    my $srclist = AptPkg::_source_list->new(@_);
+    my $xs = AptPkg::_src_records->new($srclist);
     my $self = $class->SUPER::new($xs);
     $self->_priv->{srclist} = $srclist;
     $self;
